# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/lavalite/testerlite/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Lavalite\\Testerlite\\": "packages/lavalite/testerlite/src",
            "Lavalite\\Testerlite\\Seeders\\": "packages/lavalite/testerlite/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Lavalite\Testerlite\Providers\TesterliteServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Testerlite'  => Lavalite\Testerlite\Facades\Testerlite::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Lavalite\\Testerlite\\Seeders\\TesterliteTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Lavalite\Testerlite\Providers\TesterliteServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Lavalite\Testerlite\Providers\TesterliteServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Lavalite\Testerlite\Providers\TesterliteServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/testerlite/{modulename}

**User**

    http://path-to-route-folder/user/testerlite/{modulename}

**Public**

    http://path-to-route-folder/testerlites


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/testerlite/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/testerlite/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/testerlite/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/testerlite/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/testerlite/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/testerlite/{modulename}/{slug}
    METHOD: GET