<?php

namespace Lavalite\Testerlite\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Lavalite\Testerlite\Http\Requests\TestRequest;
use Lavalite\Testerlite\Models\Test;

/**
 * Admin web controller class.
 */
class TestWorkflowController extends BaseController
{

    /**
     * Workflow controller function for test.
     *
     * @param Model   $test
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(TestRequest $request, Test $test, $step)
    {

        try {

            $test->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('testerlite::test.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/test/test/' . $test->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/test/test/' . $test->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for test.
     *
     * @param Model   $test
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Test $test, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $test->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('testerlite::test.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('testerlite::admin.test.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('testerlite::admin.test.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('testerlite::admin.test.message', $data)->render();

        }

    }
}
