<?php

namespace Lavalite\Testerlite\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Lavalite\Testerlite\Models\Test;

class TestPolicy
{

    /**
     * Determine if the given user can view the test.
     *
     * @param UserPolicyInterface $authUser
     * @param Test $test
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Test $test)
    {
        if ($authUser->canDo('testerlite.test.view') && $authUser->isAdmin()) {
            return true;
        }

        return $test->user_id == user_id() && $test->user_type == user_type();
    }

    /**
     * Determine if the given user can create a test.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('testerlite.test.create');
    }

    /**
     * Determine if the given user can update the given test.
     *
     * @param UserPolicyInterface $authUser
     * @param Test $test
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Test $test)
    {
        if ($authUser->canDo('testerlite.test.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $test->user_id == user_id() && $test->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given test.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Test $test)
    {
        return $test->user_id == user_id() && $test->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given test.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Test $test)
    {
        if ($authUser->canDo('testerlite.test.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given test.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Test $test)
    {
        if ($authUser->canDo('testerlite.test.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
