<?php

namespace Lavalite\Testerlite\Providers;

use Illuminate\Support\ServiceProvider;
use Lavalite\Testerlite\Testerlites;

class TesterliteServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'testerlite');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'testerlite');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        // $this->registerCommands();

        $this->app->register(\Lavalite\Testerlite\Providers\AuthServiceProvider::class);
        $this->app->register(\Lavalite\Testerlite\Providers\RouteServiceProvider::class);
        // $this->app->register(\Lavalite\Testerlite\Providers\EventServiceProvider::class);
        // $this->app->register(\Lavalite\Testerlite\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('lavalite.testerlite', function($app)
        {
            return $this->app->make(Testerlites::class);
        });
    }



    /**
     * Merges user's and testerlite's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'lavalite.testerlite'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/test.php', 'lavalite.testerlite.test'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Lavalite\Testerlite\Commands\Testerlite::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['lavalite.testerlite'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('lavalite/testerlite')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/testerlite')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/testerlite')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
